DisPlaceable ={
  _VERSION = 'DisPlaceable.lua 1.0.0',
  _URL     = 'http://www.modhoster.de',
  _DESCRIPTION = 'Placeable that displaces fruits',
  _LICENSE = [[
    MIT LICENSE

    Copyright (c) 2016 Eisbearg

    Permission is hereby granted, free of charge, to any person obtaining a
    copy of this software and associated documentation files (the
    "Software"), to deal in the Software without restriction, including
    without limitation the rights to use, copy, modify, merge, publish,
    distribute, sublicense, and/or sell copies of the Software, and to
    permit persons to whom the Software is furnished to do so, subject to
    the following conditions:

    The above copyright notice and this permission notice shall be included
    in all copies or substantial portions of the Software.

    THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
    OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
    MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
    IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
    CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
    TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
    SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
  ]]
}




source(Utils.getFilename("inspect.lua", g_currentModDirectory.."/scripts/"))




DisPlaceable_mt = Class(DisPlaceable, Placeable);
InitObjectClass(DisPlaceable, "DisPlaceable");


function DisPlaceable:new(isServer, isClient, customMt)
	--print("DisPlaceable:new(".." ,isServer="..inspect(isServer).." ,isClient="..inspect(isClient).." ,customMt="..inspect(customMt)..")");
    local mt = customMt or DisPlaceable_mt;
    local self = Placeable:new(isServer, isClient, mt);
    registerObjectClassName(self, "DisPlaceable");
	self.sx = 0;
	self.sz = 0;
	self.wx = 0;
	self.wz = 0;
	self.hx = 0;
	self.hz = 0;
	return self;
end;


function DisPlaceable:delete()
	--print("DisPlaceable:delete("..")");
	unregisterObjectClassName(self);
	DisPlaceable:superClass().delete(self);
end;


function DisPlaceable:deleteFinal()
	--print("DisPlaceable:deleteFinal("..")");
	DisPlaceable:superClass().deleteFinal(self);
end;


function DisPlaceable:load(xmlFilename, x,y,z, rx,ry,rz, initRandom)
	--print("DisPlaceable:load(".." ,xmlFilename="..inspect(xmlFilename).." ,x="..inspect(x).." ,rx="..inspect(rx).." ,initRandom="..inspect(initRandom)..")");
	if not DisPlaceable:superClass().load(self, xmlFilename, x,y,z, rx,ry,rz, initRandom) then
		return false;
    end;
	
	local xmlFile = loadXMLFile("temp", xmlFilename);
	local startNode = Utils.indexToObject(self.nodeId, getXMLString(xmlFile, "placeable.fruitCut#startIndex"));
	local widthNode = Utils.indexToObject(self.nodeId, getXMLString(xmlFile, "placeable.fruitCut#widthIndex"));
	local heightNode = Utils.indexToObject(self.nodeId, getXMLString(xmlFile, "placeable.fruitCut#heightIndex"));
	self.sx, _, self.sz = getWorldTranslation(startNode);
	self.wx, _, self.wz = getWorldTranslation(widthNode);
	self.hx, _, self.hz = getWorldTranslation(heightNode);
	delete(xmlFile);
  
	return true;
end;


function DisPlaceable:initPose(x,y,z, rx,ry,rz, initRandom)
	--print("DisPlaceable:initPose(".." ,x="..inspect(x).." ,rx="..inspect(rx).." ,initRandom="..inspect(initRandom)..")");
    DisPlaceable:superClass().initPose(self, x,y,z, rx,ry,rz, initRandom);
end;


function DisPlaceable:finalizePlacement()
	--print("DisPlaceable:finalizePlacement("..")");
    DisPlaceable:superClass().finalizePlacement(self);
    		
	Utils.destroyOtherFruit(FruitUtil.FRUITTYPE_GRASS, self.sx, self.sz, self.wx, self.wz, self.hx, self.hz);
	Utils.destroyOtherFruit(FruitUtil.FRUITTYPE_WHEAT, self.sx, self.sz, self.wx, self.wz, self.hx, self.hz);
end;


registerPlaceableType("DisPlaceable", DisPlaceable);
				